PCB Environment: Data Fields - Variables

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all variables with links to the structures/unions they belong to:

### - v -

- v : py::DictIterator
- values : dsn::Shape
- Via : AStarCosts
- via : dsn::Structure
- via_diameter : dsn::Net
- via_ok : dsn::Placement
- ViaRadius : NavSpacings
- vias : dsn::Net, dsn::Track, PCBoard
- Violation : AStarCosts
- VSync : UserSettings